@@ -3,7 +3,7 @@ import random
 responses_list=["As I see it, yes.", "Ask again later.", "Better not tell you now.", "Cannot predict now.", "Concentrate and ask again.", "Don’t count on it.", "It is certain.", "It is decidedly so.", "Most likely.", "My reply is no.", "My sources say no.", "Outlook not so good.", "Outlook good.", "Reply hazy, try again.", "Signs point to yes.", "Very doubtful.", "Without a doubt.", "Yes.", "Yes – definitely.", "You may rely on it."]
 
 __all__ = "__version__"
-__version__ = "0.1"
+__version__ = "2.0"
 
-async def response(self) -> str:
+async def response(question) -> str:
   return random.choice(responses_list)
